From 267a6cff648a9c2e7fab96e9126ceda0d4a631d6 Mon Sep 17 00:00:00 2001
From: "Bernhard R. Link" <brlink@debian.org>
Date: Fri, 16 Mar 2012 09:56:52 +0100
Subject: [PATCH 1/4] Dpkg::BuildFlags: add get_feature_areas()

Add a way a caller can enumerate all possible values for get_features().

Signed-off-by: Bernhard R. Link <brlink@debian.org>
---
 scripts/Dpkg/BuildFlags.pm |   19 ++++++++++++++++++-
 1 files changed, 18 insertions(+), 1 deletions(-)

diff --git a/scripts/Dpkg/BuildFlags.pm b/scripts/Dpkg/BuildFlags.pm
index 35d97c1..0c7b190 100644
--- a/scripts/Dpkg/BuildFlags.pm
+++ b/scripts/Dpkg/BuildFlags.pm
@@ -18,7 +18,7 @@ package Dpkg::BuildFlags;
 use strict;
 use warnings;
 
-our $VERSION = "1.02";
+our $VERSION = "1.03";
 
 use Dpkg::Gettext;
 use Dpkg::BuildOptions;
@@ -320,6 +320,18 @@ sub get {
     return $self->{'flags'}{$key};
 }
 
+=item $bf->get_feature_areas()
+
+Return the feature areas
+(i.e. the area values has_features will return true for).
+
+=cut
+
+sub get_feature_areas {
+    my ($self) = @_;
+    return keys $self->{'features'};
+}
+
 =item $bf->get_features($area)
 
 Return, for the given area, a hash with keys as feature names, and values
@@ -394,6 +406,11 @@ based on the package maintainer directives.
 
 New methods: $bf->get_features(), $bf->has_features(), $bf->set_feature().
 
+=head2 Version 1.03
+
+New method:  $bf->get_feature_areas() to list possible values for
+$bf->get_features.
+
 =head1 AUTHOR
 
 Raphaël Hertzog <hertzog@debian.org>
-- 
1.7.9.1

